@@ -28,6 +28,10 @@
 #include "dislocker/metadata/print_metadata.h"
 #include "dislocker/dislocker.priv.h"
 
+#include <sys/ioctl.h>
+
+#define BLKSSZGET  _IO(0x12,104)/* get block device sector size */
+
 /*
  * On Darwin and FreeBSD, files are opened using 64 bits offsets/variables
  * and O_LARGEFILE isn't defined
@@ -160,6 +164,16 @@ int dis_metadata_initialize(dis_metadata_t dis_meta)
 		return DIS_RET_ERROR_VOLUME_HEADER_READ;
 	}
 
+	//Windows 10 1903 exFAT
+	if (!dis_meta->volume_header->sector_size) {
+		uint64_t nSectorSize = 0;
+		ioctl(dis_meta_cfg->fve_fd, BLKSSZGET, &nSectorSize);
+		if(!nSectorSize)
+			nSectorSize = 512;
+		dis_meta->volume_header->sector_size = (uint16_t)nSectorSize;
+	}
+	//Windows 10 1903 exFAT
+
 	/* For debug purpose, print the volume header retrieved */
 	print_volume_header(L_DEBUG, dis_meta);
 
@@ -893,8 +907,13 @@ static int get_metadata_lazy_checked(
 		/* Get the metadata */
 		if(!get_metadata((off_t)regions[current].addr + disk_offset, metadata, fd))
 		{
+			/*
 			dis_printf(L_ERROR, "Can't get metadata (n°%d)\n", current+1);
 			return FALSE;
+			*/
+			if (++current >= 3)			//Consider metadata corruption
+				return FALSE;
+			continue;
 		}
 
 
@@ -925,8 +944,13 @@ static int get_metadata_lazy_checked(
 		ssize_t nb_read = dis_read(fd, &validations, sizeof(bitlocker_validations_t));
 		if(nb_read != sizeof(bitlocker_validations_t))
 		{
+			/*
 			dis_printf(L_ERROR, "Error, can't read all validations data.\n");
 			return FALSE;
+			*/
+			if (++current >= 3)		//Consider bad sectors
+				return FALSE;
+			continue;
 		}
 
 		/* Check the validity */
@@ -950,7 +974,7 @@ static int get_metadata_lazy_checked(
 			dis_free(*metadata);
 	}
 
-	if(current >= 3)
+	if(current > 3)
 		return FALSE;
 
 	return TRUE;
